pub struct StrategyAddressResponse {
pub strategy: StrategyType,
pub address: String,
}Fields
strategy: StrategyTypeaddress: StringTrait Implementations
Sourceimpl Clone for StrategyAddressResponse
impl Clone for StrategyAddressResponse
Sourcefn clone(&self) -> StrategyAddressResponse
fn clone(&self) -> StrategyAddressResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StrategyAddressResponse
impl Debug for StrategyAddressResponse
Sourceimpl<'de> Deserialize<'de> for StrategyAddressResponse
impl<'de> Deserialize<'de> for StrategyAddressResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StrategyAddressResponse
impl JsonSchema for StrategyAddressResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StrategyAddressResponse
impl PartialEq for StrategyAddressResponse
Sourcefn eq(&self, other: &StrategyAddressResponse) -> bool
fn eq(&self, other: &StrategyAddressResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StrategyAddressResponse
impl Serialize for StrategyAddressResponse
impl StructuralPartialEq for StrategyAddressResponse