pub struct YieldStrategy {
pub strategy_type: StrategyType,
pub address: AndrAddr,
}Fields
strategy_type: StrategyTypeaddress: AndrAddrTrait Implementations
Sourceimpl Clone for YieldStrategy
impl Clone for YieldStrategy
Sourcefn clone(&self) -> YieldStrategy
fn clone(&self) -> YieldStrategy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for YieldStrategy
impl Debug for YieldStrategy
Sourceimpl<'de> Deserialize<'de> for YieldStrategy
impl<'de> Deserialize<'de> for YieldStrategy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for YieldStrategy
impl JsonSchema for YieldStrategy
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for YieldStrategy
impl PartialEq for YieldStrategy
Sourcefn eq(&self, other: &YieldStrategy) -> bool
fn eq(&self, other: &YieldStrategy) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for YieldStrategy
impl Serialize for YieldStrategy
impl StructuralPartialEq for YieldStrategy